==> webgui_7.8.21.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Spanish/PayDriver_Cash.pm <==
package WebGUI::i18n::Spanish::PayDriver_Cash;
use utf8;
our $I18N = {
  'address' => {
    'lastUpdated' => 1222985216,
    'message' => 'Direcci&oacute;n'
  },
  'cardNumber' => {
    'lastUpdated' => 1226522200,
    'message' => 'N&uacute;mero de Tarjeta de Cr&eacute;dito'
  },
  'cash' => {
    'lastUpdated' => 1226522233,
    'message' => 'Efectivo'
  },
  'check' => {
    'lastUpdated' => 1226522242,
    'message' => 'Cheque'
  },
  'city' => {
    'lastUpdated' => 1226522252,
    'message' => 'Ciudad'
  },
  'complete transaction' => {
    'lastUpdated' => 1226522384,
    'message' => '&iquest;Completar la Transacci&oacute;n al Enviar?'
  },
  'complete transaction description' => {
    'lastUpdated' => 1226522550,
    'message' => 'Cuando se indica \'Si\', la Transacci&oacute;n se considera completa tan pronto el usuario env&iacute;a la informaci&oacute;n de pago. Cuando se indica \'No\', la Transacci&oacute;n quedar&aacute; marcada como pendiente y debe ser marcada manualmente como completa. Esto puede ser &uacute;til si Ud. desea que los usuarios puedan pagar en Efectivo pero quiere esperar a que el pago se confirme antes de completar la Transacci&oacute;n.'
  },
  'country' => {
    'lastUpdated' => 1226522583,
    'message' => 'Pa&iacute;s'
  },
  'cvv2' => {
    'lastUpdated' => 1226522615,
    'message' => 'N&uacute;mero de Verificaci&oacute;n (CVV2)'
  },
  'email' => {
    'lastUpdated' => 1226522964,
    'message' => 'Correo Electr&oacute;nico'
  },
  'emailMessage' => {
    'lastUpdated' => 1226522981,
    'message' => 'Mensaje de Correo Electr&oacute;nico'
  },
  'expiration date' => {
    'lastUpdated' => 1226522999,
    'message' => 'Fecha de Vencimiento'
  },
  'firstName' => {
    'lastUpdated' => 1226523014,
    'message' => 'Primer Nombre'
  },
  'invalid address' => {
    'lastUpdated' => 1226523108,
    'message' => 'Por favor, introduzca una direcci&oacute;n v&aacute;lida.'
  },
  'invalid city' => {
    'lastUpdated' => 1226523129,
    'message' => 'Por favor introduzca un nombre de ciudad v&aacute;lido.'
  },
  'invalid email' => {
    'lastUpdated' => 1226523157,
    'message' => 'Por favor introduzca una direcci&oacute;n de correo electr&oacute;nico v&aacute;lida.'
  },
  'invalid firstName' => {
    'lastUpdated' => 1226523183,
    'message' => 'Por favor introduzca un nombre v&aacute;lido.'
  },
  'invalid lastName' => {
    'lastUpdated' => 1226523201,
    'message' => 'Por favor introduzca un apellido v&aacute;lido.'
  },
  'invalid zip' => {
    'lastUpdated' => 1226523258,
    'message' => 'Por favor introduzca un C&oacute;digo/Zona Postal v&aacute;lida.'
  },
  'label' => {
    'lastUpdated' => 1226523270,
    'message' => 'Efectivo'
  },
  'lastName' => {
    'lastUpdated' => 1226523296,
    'message' => 'Apellido'
  },
  'module name' => {
    'lastUpdated' => 1226523316,
    'message' => 'Pago en Efectivo'
  },
  'no description' => {
    'lastUpdated' => 1226523336,
    'message' => 'Sin descripci&oacute;n.'
  },
  'other' => {
    'lastUpdated' => 1226523397,
    'message' => 'Otro'
  },
  'password' => {
    'lastUpdated' => 1226523420,
    'message' => 'Contrase&ntilde;a'
  },
  'payment method' => {
    'lastUpdated' => 1226523511,
    'message' => 'M&eacute;todo de Pago'
  },
  'phone' => {
    'lastUpdated' => 1226523528,
    'message' => 'N&uacute;mero Telef&oacute;nico'
  },
  'state' => {
    'lastUpdated' => 1226523546,
    'message' => 'Estado/Provincia/Departamento'
  },
  'use cvv2' => {
    'lastUpdated' => 1226523564,
    'message' => 'Usar CVV2'
  },
  'vendorId' => {
    'lastUpdated' => 1226523627,
    'message' => 'Usuario (ID del Vendedor)'
  },
  'zipcode' => {
    'lastUpdated' => 1226523644,
    'message' => 'C&oacute;digo/Zona Postal'
  }
}
;

1;

==> webgui_7.10.29.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Spanish/PayDriver_Cash.pm <==
package WebGUI::i18n::Spanish::PayDriver_Cash;
use utf8;
our $I18N = {
  'Pay' => {
    'lastUpdated' => '1276813347',
    'message' => 'Pagar'
  },
  'address' => {
    'lastUpdated' => '1222985216',
    'message' => 'Direcci&oacute;n'
  },
  'cardNumber' => {
    'lastUpdated' => '1226522200',
    'message' => 'N&uacute;mero de Tarjeta de Cr&eacute;dito'
  },
  'cart summary template' => {
    'lastUpdated' => '1276813366',
    'message' => 'Plantilla para Resumen de Carrito -- Pago en Efectivo'
  },
  'cash' => {
    'lastUpdated' => '1226522233',
    'message' => 'Efectivo'
  },
  'check' => {
    'lastUpdated' => '1226522242',
    'message' => 'Cheque'
  },
  'city' => {
    'lastUpdated' => '1226522252',
    'message' => 'Ciudad'
  },
  'complete transaction' => {
    'lastUpdated' => '1226522384',
    'message' => '&iquest;Completar la Transacci&oacute;n al Enviar?'
  },
  'complete transaction description' => {
    'lastUpdated' => '1226522550',
    'message' => 'Cuando se indica \'Si\', la Transacci&oacute;n se considera completa tan pronto el usuario env&iacute;a la informaci&oacute;n de pago. Cuando se indica \'No\', la Transacci&oacute;n quedar&aacute; marcada como pendiente y debe ser marcada manualmente como completa. Esto puede ser &uacute;til si Ud. desea que los usuarios puedan pagar en Efectivo pero quiere esperar a que el pago se confirme antes de completar la Transacci&oacute;n.'
  },
  'country' => {
    'lastUpdated' => '1226522583',
    'message' => 'Pa&iacute;s'
  },
  'cvv2' => {
    'lastUpdated' => '1226522615',
    'message' => 'N&uacute;mero de Verificaci&oacute;n (CVV2)'
  },
  'email' => {
    'lastUpdated' => '1226522964',
    'message' => 'Correo Electr&oacute;nico'
  },
  'emailMessage' => {
    'lastUpdated' => '1226522981',
    'message' => 'Mensaje de Correo Electr&oacute;nico'
  },
  'expiration date' => {
    'lastUpdated' => '1226522999',
    'message' => 'Fecha de Vencimiento'
  },
  'firstName' => {
    'lastUpdated' => '1226523014',
    'message' => 'Primer Nombre'
  },
  'invalid address' => {
    'lastUpdated' => '1226523108',
    'message' => 'Por favor, introduzca una direcci&oacute;n v&aacute;lida.'
  },
  'invalid city' => {
    'lastUpdated' => '1226523129',
    'message' => 'Por favor introduzca un nombre de ciudad v&aacute;lido.'
  },
  'invalid email' => {
    'lastUpdated' => '1226523157',
    'message' => 'Por favor introduzca una direcci&oacute;n de correo electr&oacute;nico v&aacute;lida.'
  },
  'invalid firstName' => {
    'lastUpdated' => '1226523183',
    'message' => 'Por favor introduzca un nombre v&aacute;lido.'
  },
  'invalid lastName' => {
    'lastUpdated' => '1226523201',
    'message' => 'Por favor introduzca un apellido v&aacute;lido.'
  },
  'invalid zip' => {
    'lastUpdated' => '1226523258',
    'message' => 'Por favor introduzca un C&oacute;digo/Zona Postal v&aacute;lida.'
  },
  'label' => {
    'lastUpdated' => '1226523270',
    'message' => 'Efectivo'
  },
  'lastName' => {
    'lastUpdated' => '1226523296',
    'message' => 'Apellido'
  },
  'module name' => {
    'lastUpdated' => '1226523316',
    'message' => 'Pago en Efectivo'
  },
  'no description' => {
    'lastUpdated' => '1226523336',
    'message' => 'Sin descripci&oacute;n.'
  },
  'other' => {
    'lastUpdated' => '1226523397',
    'message' => 'Otro'
  },
  'password' => {
    'lastUpdated' => '1226523420',
    'message' => 'Contrase&ntilde;a'
  },
  'payment method' => {
    'lastUpdated' => '1226523511',
    'message' => 'M&eacute;todo de Pago'
  },
  'phone' => {
    'lastUpdated' => '1226523528',
    'message' => 'N&uacute;mero Telef&oacute;nico'
  },
  'state' => {
    'lastUpdated' => '1226523546',
    'message' => 'Estado/Provincia/Departamento'
  },
  'summary template' => {
    'lastUpdated' => '1276813377',
    'message' => 'Plantilla con Resumen de Carrito'
  },
  'summary template help' => {
    'lastUpdated' => '1276813411',
    'message' => 'Seleccione la plantilla a emplear para desplegar el formulario en que el usuario confirma el pago de su carrito de compras.'
  },
  'use cvv2' => {
    'lastUpdated' => '1226523564',
    'message' => 'Usar CVV2'
  },
  'vendorId' => {
    'lastUpdated' => '1226523627',
    'message' => 'Usuario (ID del Vendedor)'
  },
  'zipcode' => {
    'lastUpdated' => '1226523644',
    'message' => 'C&oacute;digo/Zona Postal'
  }
}
;

1;
